<?php
/**
 * Klasa routingu
 *
 */
class MfRouter  extends DataObject {

	/**
	 * nazwa tabeli
	 */
	static $tableName = 'mf_router';

	/**
	 * nazwa klucza tabeli
	 */
	static $classTablePK = 'id_mf_router';

	/**
	 * nazwa klasy
	 */
	static $className = __CLASS__;

	/**
	 * tabela mapująca pola z bazy SQL na pola klasy.
	 */
	static $fields = array(
	'id_mf_router' =>'id',
	'name' =>'name',
	'url' =>'url',
	'controller' =>'controller',
	'method' =>'method',
	'paramMatrix'=>'paramMatrix',
	'config'=>'config',
	'id_mf_module'=>'idMfModule',
	'param'=>'param',
	'label_url'=>'labelUrl',
	'location'=>'location',
	'lang'=>'lang'
	);

	protected $id;
	private $name;
	private $url;
	private $controller;
	private $method;
	private $paramMatrix;
	private $config;
	private $matchUri;
	private $param;
	private $idMfModule;
	private $labelUrl;
	private $location;
	private $lang;

	public function GetId() {
		return $this->id;
	}

	public function SetId($id) {
		$this->id = $id;
	}

	public function GetName() {
		return $this->name;
	}

	public function SetName($name) {
		$this->name = $name;
	}

	public function GetUrl() {
		return $this->url;
	}

	public function SetUrl($url) {
		$this->url = $url;
	}

	public function GetController() {
		return $this->controller;
	}

	public function SetController($controller) {
		$this->controller = $controller;
	}

	public function GetMethod() {
		return $this->method;
	}

	public function SetMethod($method) {
		$this->method = $method;
	}

	public function GetParamMatrix() {
		return $this->paramMatrix;
	}

	public function SetParamMatrix($paramMatrix) {
		$this->paramMatrix = $paramMatrix;
	}

	public function GetConfig() {
		return $this->config;
	}

	public function SetConfig($config) {
		$this->config = $config;
	}

	public function GetMatchUri() {
		return $this->matchUri;
	}

	public function SetMatchUri($matchUri) {
		$this->matchUri = $matchUri;
	}

	public function GetParam() {
		return $this->param;
	}

	public function SetParam($param) {
		$this->param = $param;
	}
	public function GetIdMfModule() {
		return $this->idMfModule;
	}

	public function SetIdMfModule($idMfModule) {
		$this->idMfModule = $idMfModule;
	}
	
	public function GetLabelUrl() {
		return $this->labelUrl;
	}

	public function SetLabelUrl($labelUrl) {
		$this->labelUrl = $labelUrl;
	}
	
	public function GetLocation() {
		return $this->location;
	}

	public function SetLocation($location) {
		$this->location = $location;
	}

	public function GetLang() {
		return $this->lang;
	}

	public function SetLang($lang) {
		$this->lang = $lang;
	}




	public function __construct($id = -1) {
		$this->SetId($id);
	}

	/**
	 * Pobiera nazwę tabeli reprezentującej obiekt w SQL
	 * @return string
	 */

	public  function GetTableName(){
		return self::$tableName;
	}
	/**
       * Pobiera taablice mapującą pola klasy na pola tabeli
       * @return array
       */
	public  function GetFields(){
		return self::$fields;
	}
	/**
       * Pobiera nazwę klasy
       * @return string
       */
	public  function GetClassName(){
		return self::$className;
	}


	public function GetClassTablePK() {
		return self::$classTablePK;
	}
}
?>